==> kyt-1.2.5.tgz: package/lib/actions/build.js <==
"use strict";

// Command to build production code
var shell = require('shelljs');

var logger = require('kyt-utils/logger');

var _require = require('kyt-utils/paths')(),
    buildPath = _require.buildPath,
    publicBuildPath = _require.publicBuildPath,
    publicSrcPath = _require.publicSrcPath;

var printAssets = require('../utils/printAssets');

var buildConfigs = require('../utils/buildConfigs');

var webpackCompiler = require('../utils/webpackCompiler');

module.exports = function (config) {
  logger.start('Starting production build...');
  var clientCompiler;
  var serverCompiler;

  var _buildConfigs = buildConfigs(config, 'production'),
      clientConfig = _buildConfigs.clientConfig,
      serverConfig = _buildConfigs.serverConfig; // Clean the build directory.


  if (shell.rm('-rf', buildPath).code === 0) {
    shell.mkdir(buildPath);
    logger.task('Cleaned ./build');
  } // Copy public folder into build


  if (shell.test('-d', publicSrcPath)) {
    // Create build folder if it doesnt exist
    if (!shell.test('-d', buildPath)) {
      shell.mkdir(buildPath);
    }

    shell.cp('-r', publicSrcPath, publicBuildPath);
    logger.task('Copied /src/public to /build/public');
  } else {
    shell.mkdir('-p', "".concat(buildPath, "/public"));
  } // Compiles server code using the prod.server config


  var buildServer = function buildServer() {
    serverCompiler = webpackCompiler(serverConfig, function (stats) {
      if (stats.hasErrors()) process.exit(1);
      logger.end('Done building');
    });
    serverCompiler.run(function () {
      return undefined;
    });
  };

  var buildClient = function buildClient() {
    clientCompiler = webpackCompiler(clientConfig, function (stats) {
      if (stats.hasErrors()) process.exit(1);
      logger.info('Assets:');
      printAssets(stats, clientConfig);

      if (config.hasServer) {
        buildServer();
      } else {
        logger.end('Done building');
      }
    });
    clientCompiler.run(function () {
      return undefined;
    });
  };

  if (config.hasClient) {
    buildClient();
  } else {
    buildServer();
  }
};

==> kyt-1.2.9.tgz: package/lib/actions/build.js <==
"use strict";

// Command to build production code

var shell = require('shelljs');
var logger = require('kyt-utils/logger');
var _require = require('kyt-utils/paths')(),
  buildPath = _require.buildPath,
  publicBuildPath = _require.publicBuildPath,
  publicSrcPath = _require.publicSrcPath;
var printAssets = require('../utils/printAssets');
var buildConfigs = require('../utils/buildConfigs');
var webpackCompiler = require('../utils/webpackCompiler');
module.exports = function (config) {
  logger.start('Starting production build...');
  var clientCompiler;
  var serverCompiler;
  var _buildConfigs = buildConfigs(config, 'production'),
    clientConfig = _buildConfigs.clientConfig,
    serverConfig = _buildConfigs.serverConfig;

  // Clean the build directory.
  if (shell.rm('-rf', buildPath).code === 0) {
    shell.mkdir(buildPath);
    logger.task('Cleaned ./build');
  }

  // Copy public folder into build
  if (shell.test('-d', publicSrcPath)) {
    // Create build folder if it doesnt exist
    if (!shell.test('-d', buildPath)) {
      shell.mkdir(buildPath);
    }
    shell.cp('-r', publicSrcPath, publicBuildPath);
    logger.task('Copied /src/public to /build/public');
  } else {
    shell.mkdir('-p', "".concat(buildPath, "/public"));
  }

  // Compiles server code using the prod.server config
  var buildServer = function buildServer() {
    serverCompiler = webpackCompiler(serverConfig, function (stats) {
      if (stats.hasErrors()) process.exit(1);
      logger.end('Done building');
    });
    serverCompiler.run(function () {
      return undefined;
    });
  };
  var buildClient = function buildClient() {
    clientCompiler = webpackCompiler(clientConfig, function (stats) {
      if (stats.hasErrors()) process.exit(1);
      logger.info('Assets:');
      printAssets(stats, clientConfig);
      if (config.hasServer) {
        buildServer();
      } else {
        logger.end('Done building');
      }
    });
    clientCompiler.run(function () {
      return undefined;
    });
  };
  if (config.hasClient) {
    buildClient();
  } else {
    buildServer();
  }
};
